Signals — flatland 0.8.1 documentation

# Signals

Flatland can notify your code when events of interest occur during flatland processing using `Blinker` signals. These signals can be used for advanced customization in your application or simply as a means for tracing and logging flatland activity during development.

`element_set` = <blinker.base.NamedSignal object at 0x7f471ce81310; 'element_set'>

  Emitted after `set()` has been called on an element.

  Parameters: | sender – the element adapted – boolean, True if the set() adapted successfully.

`validator_validated` = <blinker.base.NamedSignal object at 0x7f471ceb8210; 'validator_validated'>

  Emitted after a validator has processed an element.

  Parameters: | sender – the validator callable doing validation element – the element being validated state – the state passed to `validate()` result – the result of validator execution